@@ -183,29 +183,6 @@ _debug_announce_rect (char *msg, GdkRectangle rect)
 		 msg, rect.x, rect.y, rect.x + rect.width, rect.y + rect.height);
 }
 
-#ifdef TEST_XTST_CURSOR
-static Cursor *
-_get_x_cursors (Display *display)
-{
-	int n_x_font_cursors = XC_num_glyphs; 
-	int dummy;
-	if (!XTestQueryExtension (display, &dummy, &dummy,&dummy, &dummy))
-		fprintf (stderr, "WARNING: XTEST extension not available!\n");
-	if (x_cursors == NULL && display) {
-		int i;
-		x_cursors = g_new0 (Cursor, XC_num_glyphs);
-		for (i = 2; i < n_x_font_cursors; i += 2)
-		{
-			if (i == 30)
-				x_cursors[i] = XCreateFontCursor (display, XC_xterm);
-			else
-				x_cursors[i] = XCreateFontCursor (display, i);
-		}
-	}
-	return x_cursors;
-}
-#endif
-
 static gboolean
 _diff_pixbufs (const GdkPixbuf *a, const GdkPixbuf *b)
 {
@@ -565,34 +542,22 @@ zoom_region_clip_to_exposed_target (ZoomRegion *zoom_region,
 	GNOME_Magnifier_RectBounds onscreen_target, *source_area;
 	source_area = &zoom_region->priv->source_area;
 
-	onscreen_target.x1 = MAX (zoom_region->priv->exposed_bounds.x1 / zoom_region->xscale,
-				  source_area->x1);
-	onscreen_target.y1 = MAX (zoom_region->priv->exposed_bounds.y1 / zoom_region->yscale,
-				  source_area->y1);
-	onscreen_target.x2 = MIN (zoom_region->priv->exposed_bounds.x2 / zoom_region->xscale,
-				  source_area->x2);
-	onscreen_target.y2 = MIN (zoom_region->priv->exposed_bounds.y2 / zoom_region->yscale,
-				  source_area->y2);
+	onscreen_target.x1 = MAX (floor (zoom_region->priv->exposed_bounds.x1
+					 / zoom_region->xscale),
+					 source_area->x1);
+	onscreen_target.y1 = MAX (floor (zoom_region->priv->exposed_bounds.y1
+					 / zoom_region->yscale),
+					 source_area->y1);
+	onscreen_target.x2 = MIN (ceil (zoom_region->priv->exposed_bounds.x2
+					/ zoom_region->xscale),
+					source_area->x2);
+	onscreen_target.y2 = MIN (ceil (zoom_region->priv->exposed_bounds.y2
+					/ zoom_region->yscale),
+					source_area->y2);
 
 	return _rectangle_clip_to_bounds (area, &onscreen_target);
 }
 
-#ifdef NEEDED
-static GdkRectangle
-zoom_region_clip_to_exposed_bounds (ZoomRegion *zoom_region,
-				    GdkRectangle area)
-{
-	return _rectangle_clip_to_bounds (area, &zoom_region->priv->exposed_bounds);
-}
-
-static GdkRectangle
-zoom_region_clip_to_viewport (ZoomRegion *zoom_region,
-			      GdkRectangle area)
-{
-	return _rectangle_clip_to_bounds (area, &zoom_region->priv->exposed_viewport);
-}
-#endif
-
 static GdkRectangle
 zoom_region_clip_to_scaled_pixmap (ZoomRegion *zoom_region,
 				   GdkRectangle area)
@@ -638,8 +603,8 @@ zoom_region_source_rect_from_view_bounds (ZoomRegion *zoom_region,
 			       / zoom_region->xscale);
 	source_rect.y = floor ((view_bounds->y1 + zoom_region->priv->exposed_bounds.y1)
 				/ zoom_region->yscale);
-	source_rect.width = ceil ((view_bounds->x2 - view_bounds->x1) / zoom_region->xscale);
-	source_rect.height = ceil ((view_bounds->y2 - view_bounds->y1) / zoom_region->yscale);
+	source_rect.width = ceil ((view_bounds->x2 - view_bounds->x1) / zoom_region->xscale) + 1;
+	source_rect.height = ceil ((view_bounds->y2 - view_bounds->y1) / zoom_region->yscale) + 1;
 	return source_rect;
 }
 
@@ -666,8 +631,8 @@ zoom_region_source_rect_from_view_rect (ZoomRegion *zoom_region,
 			       / zoom_region->xscale);
 	source_rect.y = floor ((view_rect.y + zoom_region->priv->exposed_bounds.y1)
 				/ zoom_region->yscale);
-	source_rect.width = ceil (view_rect.width / zoom_region->xscale);
-	source_rect.height = ceil (view_rect.height / zoom_region->yscale);
+	source_rect.width = ceil (view_rect.width / zoom_region->xscale) + 1;
+	source_rect.height = ceil (view_rect.height / zoom_region->yscale) + 1;
 	return source_rect;
 }
 
@@ -1425,20 +1390,6 @@ zoom_region_set_cursor_pos (ZoomRegion *zoom_region, int x, int y)
 	}
 }
 
-#ifdef TEST_XTST_CURSOR
-static GdkWindow *
-zoom_region_source_root (ZoomRegion *zoom_region)
-{
-	GdkScreen *source_screen = NULL;
-	if (zoom_region->priv->source_drawable)
-		source_screen =
-			gdk_drawable_get_screen (zoom_region->priv->source_drawable);
-	if (source_screen)
-		return gdk_screen_get_root_window (source_screen);
-	else return NULL;
-}
-#endif
-
 static gboolean
 zoom_region_update_pointer (ZoomRegion *zoom_region, gboolean draw_cursor)
 {
@@ -2026,57 +1977,6 @@ zoom_region_time_frame(ZoomRegion *zoom_region, Magnifier *magnifier)
 	}
 }
 
-void
-exit_report(ZoomRegion *zoom_region)
-{
-	float frame_avg;
-	float x_scroll_incr, y_scroll_incr;
-	int width, height, x, y;
-
-	if (timing_test) {
-		width = (zoom_region->priv->exposed_viewport.x2 -
-			zoom_region->priv->exposed_viewport.x1) / zoom_region->xscale;
-		height = (zoom_region->priv->exposed_viewport.y2 -
-			zoom_region->priv->exposed_viewport.y1) / zoom_region->yscale;
-
-		frame_avg = mag_timing.frame_total / mag_timing.num_frame_samples;
-
-		x_scroll_incr = (float)mag_timing.dx_total / (float)mag_timing.num_line_samples;
-		y_scroll_incr = (float)mag_timing.dy_total / (float)mag_timing.num_line_samples;
-
-		gdk_drawable_get_size (GDK_DRAWABLE (zoom_region->priv->w->window),
-			&x, &y);
-
-		fprintf(stderr, "\nFinal Report:\n\n");
-
-		fprintf(stderr, "  Frames Processed         = %ld\n", 
-			mag_timing.num_frame_samples + 1);
-		fprintf(stderr, "  Width/Height/Depth       = %d/%d/%d\n", x, y,
-			gdk_drawable_get_depth (zoom_region->priv->w->window));
-		fprintf(stderr, "  Zoom Factor (x/y)        = %f/%f\n", zoom_region->xscale,
-			zoom_region->yscale);
-		fprintf(stderr, "  Pan Latency              = (avg. %f) (max. %f) seconds\n",
-			(mag_timing.idle_total / mag_timing.num_idle_samples), timing_idle_max);
-		fprintf(stderr, "  Total Frame Duration     = (avg. %f) (max. %f) (tot. %f) seconds\n",
-			frame_avg, timing_frame_max, mag_timing.frame_total);
-		fprintf(stderr, "  Frame Rate               = (avg. %f) (max. %f) frames/second\n",
-			1.0 / (mag_timing.frame_total / mag_timing.num_frame_samples), cps_max);
-		fprintf(stderr, "  Scroll Delta (x)         = (avg. %f) (tot. %d) lines\n",
-			x_scroll_incr, mag_timing.dx_total);
-		fprintf(stderr, "  Scroll Delta (y)         = (avg. %f) (tot. %d) lines\n",
-			y_scroll_incr, mag_timing.dy_total);
-		fprintf(stderr, "  Scroll Rate (x)          = (avg. %f) lines/second\n",
-			x_scroll_incr / frame_avg);
-		fprintf(stderr, "  Scroll Rate (y)          = (avg. %f) lines/second\n",
-			y_scroll_incr / frame_avg);
-
-		fprintf(stderr, "  Net Render Rate          = (avg. %f) (max. %f) Mpex/second\n\n",
-			(height * width *
-			((float)mag_timing.num_frame_samples / (float)mag_timing.frame_total)) / 1000000.0,
-			nrr_max / 1000000.0);
-	}
-}
-
 static void
 zoom_region_sync (ZoomRegion *zoom_region)
 {
@@ -2411,12 +2311,12 @@ zoom_region_set_property (BonoboPropertyBag *bag,
 		break;
 	case ZOOM_REGION_XALIGN_PROP:
 		zoom_region->x_align_policy = BONOBO_ARG_GET_INT (arg);
-		zoom_region_update_current (zoom_region);
+		zoom_region_align (zoom_region);
 		break;
 	case ZOOM_REGION_YALIGN_PROP:
 		/* TODO: enums here */
 		zoom_region->y_align_policy = BONOBO_ARG_GET_INT (arg);
-		zoom_region_update_current (zoom_region);
+		zoom_region_align (zoom_region);
 		break;
 	case ZOOM_REGION_VIEWPORT_PROP:
 		bounds = BONOBO_ARG_GET_GENERAL (arg,
