@@ -201,6 +201,27 @@ int main(int argc, char ** argv){
 		bonobo_pbclient_set_ulong (properties, "cursor-color", 0x255, NULL);
 		bonobo_object_release_unref (properties, NULL);
 		break;
+	case 'a':
+		properties = GNOME_Magnifier_ZoomRegion_getProperties (zoom_region, &ev);
+		switch (bonobo_pbclient_get_long (properties, "x-alignment", NULL)) {
+		case GNOME_Magnifier_ZoomRegion_ALIGN_CENTER:
+			bonobo_pbclient_set_long (properties, "x-alignment", GNOME_Magnifier_ZoomRegion_ALIGN_MIN, NULL);
+			bonobo_pbclient_set_long (properties, "y-alignment", GNOME_Magnifier_ZoomRegion_ALIGN_MIN, NULL);
+			break;
+		case GNOME_Magnifier_ZoomRegion_ALIGN_MIN:
+			bonobo_pbclient_set_long (properties, "x-alignment", GNOME_Magnifier_ZoomRegion_ALIGN_MAX, NULL);
+			bonobo_pbclient_set_long (properties, "y-alignment", GNOME_Magnifier_ZoomRegion_ALIGN_MAX, NULL);
+			break;
+		case GNOME_Magnifier_ZoomRegion_ALIGN_MAX:
+			bonobo_pbclient_set_long (properties, "x-alignment", GNOME_Magnifier_ZoomRegion_ALIGN_CENTER, NULL);
+			bonobo_pbclient_set_long (properties, "y-alignment", GNOME_Magnifier_ZoomRegion_ALIGN_CENTER, NULL);
+			break;
+		}
+		bonobo_object_release_unref (properties, NULL);
+		break;
+	case 'x':
+		GNOME_Magnifier_Magnifier_dispose (magnifier, &ev);
+		break;
         case 'S':
 		properties = GNOME_Magnifier_Magnifier_getProperties (magnifier, &ev);
 		bonobo_pbclient_set_long (properties, "cursor-size", 200, NULL);
